pub struct FileTreeProps {
pub class: Class,
pub file_class: Class,
pub current_dir: Option<PathBuf>,
pub tree_id: String,
pub icon_size: u32,
pub opened: bool,
pub on_click: Option<EventHandler<PathBuf>>,
}Expand description
The FileTree properties struct for the configuration of the component.
Fields
class: ClassThe class attribute for the component.
file_class: ClassThe class attribute for files in the current directory.
current_dir: Option<PathBuf>The current directory.
tree_id: StringAn identifer of the tree.
icon_size: u32The size of the icon.
opened: boolA flag to indicate whether the directory is opened or not.
on_click: Option<EventHandler<PathBuf>>An event handler to be called when a file is clicked.
Implementations
Sourceimpl FileTreeProps
impl FileTreeProps
Sourcepub fn builder() -> FileTreePropsBuilder<((), (), (), (), (), (), ())>
pub fn builder() -> FileTreePropsBuilder<((), (), (), (), (), (), ())>
Create a builder for building FileTreeProps.
On the builder, call .class(...)(optional), .file_class(...)(optional), .current_dir(...)(optional), .tree_id(...), .icon_size(...)(optional), .opened(...)(optional), .on_click(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FileTreeProps.